﻿using System;
using System.IO;
using System.Text.RegularExpressions;
using Zeta.Bot;
using Zeta.Bot.Profile;
using Zeta.Game;
using Zeta.TreeSharp;
using Zeta.XmlEngine;
using Action = Zeta.TreeSharp.Action;

namespace QuestTools
{
    [XmlElement("RestartAct")]
    public class RestartAct : ProfileBehavior
    {
        private bool _isDone = false;
        public override bool IsDone { get { return _isDone; } }

        public override void OnStart()
        {
            Logger.Log("RestartAct initialized");
        }

        protected override Composite CreateBehavior()
        {
            return
            new Action(ret => ForceRestartAct());
        }

        private RunStatus ForceRestartAct()
        {
            Regex questingProfileName = new Regex(@"Act \d by rrrix");

            string act = "";
            string difficulty = "";

            switch (ZetaDia.CurrentAct)
            {
                case Act.A1: act = "Act1";
                    break;
                case Act.A2: act = "Act2";
                    break;
                case Act.A3: act = "Act3";
                    break;
                case Act.A4: act = "Act4";
                    break;
                default:
                    break;
            }
            switch (ZetaDia.Service.Hero.CurrentDifficulty)
            {
                case GameDifficulty.Normal: difficulty = "Normal";
                    break;
                case GameDifficulty.Hard: difficulty = "Hard";
                    break;
                case GameDifficulty.Expert: difficulty = "Expert";
                    break;
                case GameDifficulty.Master: difficulty = "Master";
                    break;
                case GameDifficulty.Torment1: difficulty = "Torment1";
                    break;
                case GameDifficulty.Torment2: difficulty = "Torment2";
                    break;
                case GameDifficulty.Torment3: difficulty = "Torment3";
                    break;
                case GameDifficulty.Torment4: difficulty = "Torment4";
                    break;
                case GameDifficulty.Torment5: difficulty = "Torment5";
                    break;
                case GameDifficulty.Torment6: difficulty = "Torment6";
                    break;
            }

            string restartActProfile = String.Format("{0}_StartNew{1}.xml", act, difficulty);
            Logger.Log("[QuestTools] Restarting Act - loading {0}", restartActProfile);

            string profilePath = Path.Combine(Path.GetDirectoryName(ProfileManager.CurrentProfile.Path), restartActProfile);
            ProfileManager.Load(profilePath);

            return RunStatus.Success;
        }
        public override void ResetCachedDone()
        {
            _isDone = false;
            base.ResetCachedDone();
        }
    }
}
